/*
    AccountName

    Copyright (c) 2009 by Yuzik Menski <no@route.here>
						  Ruslan Nigmatullin <euroelessar@gmail.com>

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************
*/

#include "accountname.h"
#include <QDebug>

#if defined(FORCE_UREF)
inline QDebug & operator<<(QDebug debug, const TreeModelItem & item)
#else
inline QDebug operator<<(QDebug debug, const TreeModelItem & item)
#endif
{
    debug.nospace() << "TreeModelItem( " << item.
	m_protocol_name << ", " << item.m_account_name << ", " << item.
	m_item_name << ", " << item.m_parent_name << ", " << item.
	m_item_history << ", " << item.m_item_type << " )";
    return debug.space();
}

bool AccountNamePlugin::init(PluginSystemInterface * plugin_system)
{
	m_plugin_system = plugin_system;
	m_item_added = plugin_system->registerEventHandler("Core/ContactList/ItemAdded", this);
	m_icon = 0;

	return true;
}

void AccountNamePlugin::release()
{
}

void AccountNamePlugin::processEvent(Event & event)
{
	if (event.id != m_item_added)
		return;

	if (event.args.size() < 1)
		return;
	TreeModelItem & item = event.at<TreeModelItem>(0);

	if (item.m_item_type != 2)
		return;

	QString protocol_name = item.m_protocol_name == "ICQ" ? "ICQ" : item.m_protocol_name.toLower();
	QSettings settings(QSettings::defaultFormat(), QSettings::UserScope,
			   "qutim/qutim." + m_profile_name + "/" + protocol_name + "." +
			   item.m_account_name, "accountsettings");

	QString accountName = settings.value("main/nickname").toString();
	if (accountName == "")
		accountName = settings.value("main/nick").toString();

	if (accountName == "" || accountName == item.m_item_name)
		return;

	accountName += " (" + item.m_account_name + ")";

	item.m_item_name = accountName;
	m_plugin_system->setContactItemName(item, accountName);
}

void AccountNamePlugin::setProfileName(const QString & profile_name)
{
	m_profile_name = profile_name;
}

QString AccountNamePlugin::name()
{
	return "AccountName";
}

QString AccountNamePlugin::description()
{
	return "Implemenation of accounts name update";
}

QString AccountNamePlugin::type()
{
	return "simple";
}

QIcon *AccountNamePlugin::icon()
{
	return m_icon;
}

Q_EXPORT_PLUGIN2(accountname, AccountNamePlugin);
